#!/usr/bin/env bash

# A wrapper for corrplot r function
#
# Author: Jingcheng Yang
# Email: yjcyxky@163.com
#
# License: MIT

# Exit on error. Append "|| true" if you expect an error.
# set -o errexit
# Exit on error inside any functions or subshells.
# set -o errtrace
# Do not allow use of undefined vars. Use ${VAR:-} to use an undefined VAR
set -o nounset
# Catch the error in case mysqldump fails (but gzip succeeds) in `mysqldump |gzip`
set -o pipefail
# Turn on traces, useful while debugging but commented out by default
# set -o xtrace

show_help() {
	cat <<EOF
usage: $(echo $0) [-d <INPUT_FILE>] [-o <OUTPUT_FILE>]
       -i INPUT_FILE An argument json file.
       -o OUTPUT_FILE A plotly json file.
EOF
}

while getopts ":hi:o:" arg; do
	case "$arg" in
	"i")
		INPUT_FILE="$OPTARG"
		;;
	"o")
		OUTPUT_FILE="$OPTARG"
		;;
	"?")
		echo "Unkown option: $OPTARG"
		exit 1
		;;
	":")
		echo "No argument value for option $OPTARG"
		;;
	h)
		show_help
		exit 0
		;;
	*)
		echo "Unknown error while processing options"
		show_help
		exit 1
		;;
	esac
done

if [ -z "$INPUT_FILE" ]; then
	echo "-i argument is not specified."
	exit 1
elif [ ! -f "$INPUT_FILE" ]; then
	echo "$INPUT_FILE is not a valid file."
	exit 1
else
	INPUT_FILE=$(realpath $INPUT_FILE)
fi

if [ -z "$OUTPUT_FILE" ]; then
	echo "-o argument is not specified."
	exit 1
elif [ ! -f "$OUTPUT_FILE" ]; then
	echo "$OUTPUT_FILE is not a valid file."
	exit 1
else
	OUTPUT_FILE=$(realpath $OUTPUT_FILE)
fi

TEMP=$(mktemp)

echo "Run script: $TEMP"

SCRIPT_DIR=`realpath $(dirname $0)`

cat <<EOF >"$TEMP"
#!/usr/bin/env Rscript

run <- function() {
	# Print traceback message
	on.exit(traceback())
  source("${SCRIPT_DIR}/corrplot.R")
  corrplot("${INPUT_FILE}", "${OUTPUT_FILE}")
}

run()
EOF

printf "\n---------------------\n"
cat "$TEMP"
echo "---------------------"

Rscript $TEMP
