(ns tservice.plugins.corrplot.common
  (:require [selmer.parser :as parser]
            [tservice.lib.files :refer [get-path-variable]]
            [clojure.java.shell :as shell :refer [sh]]
            [tservice.lib.fs :as fs-lib]
            [clojure.data.json :as json]
            [clojure.tools.logging :as log]))

(defn add-env-to-path
  [plugin-env-dir]
  (let [env-bin-path (fs-lib/join-paths plugin-env-dir "bin")
        path (get-path-variable)]
    (str env-bin-path ":" path)))

(defn make-args-json!
  "Render arguments json file."
  [template-file context output-file]
  (log/info (format "Render Template (%s) with Environment Context: %s" template-file context))
  (let [template (slurp template-file)
        args-json (parser/render template context)]
    (spit output-file (json/write-str args-json))))

(defn call-corrplot!
  [input-file output-file plugin-env-dir]
  (shell/with-sh-env {:PATH   (add-env-to-path plugin-env-dir)
                      :R_PROFILE_USER (fs-lib/join-paths plugin-env-dir "Rprofile")
                      :LC_ALL "en_US.utf-8"
                      :LANG   "en_US.utf-8"}
    (let [command ["bash" "-c" (format "corrplot.sh -i %s -o %s" input-file output-file)]
          result (apply sh command)
          status (if (= (:exit result) 0) "Success" "Error")
          msg (str (:out result) "\n" (:err result))]
      {:status status
       :msg msg})))
